/*
 * WalletPassphrase.java
 *
 * Copyright 2014 the curewallet.org.
 * http://www.curewallet.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.curewallet.lib.api;

import org.curewallet.lib.api.result.WalletPassphraseResult;
import org.curewallet.lib.jsonrpc.JsonRPCClient;

/**
 * walletpassphrase<br>
 * ウォレットをアンロックするための複合キーをメモリに保存するためのAPIです。
 * 
 * @author Nezumi Kozo
 * @since 1.0
 */
public interface WalletPassphrase extends CoinAPI {

	/**
	 * ウォレットをアンロックするための複合キーをメモリに保存します。
	 * 
	 * @param jsonRPCClient JSON-RPCクライアント
	 * @param passphrase パスフレーズ
	 * @param timeout メモリに保存する時間(second)
	 * @return 実行結果
	 * @throws CoinAPIException 失敗
	 * @since 1.0
	 */
	public WalletPassphraseResult call(JsonRPCClient jsonRPCClient, String passphrase, Long timeout) throws CoinAPIException;

	/**
	 * ウォレットをアンロックするための複合キーをメモリに保存します。
	 * 
	 * @param jsonRPCClient JSON-RPCクライアント
	 * @param passphrase パスフレーズ
	 * @param timeout メモリに保存する時間(second)
	 * @return 実行結果
	 * @throws CoinAPIException 失敗
	 * @since 1.0
	 */
	public WalletPassphraseResult call(JsonRPCClient jsonRPCClient, String passphrase, Integer timeout) throws CoinAPIException;


}
